# V-Tag

Easily create and store different version of you file on the fly.

## Installation

```commandline
pip install v-tag
```

## Usage / Docs

After installation run the following command

```
vtag --help
```

This will a list of all the commands and their functions.
